@@ -19,15 +19,20 @@
 package org.sleuthkit.datamodel;
 
 import java.io.Serializable;
+import java.io.UnsupportedEncodingException;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.ResourceBundle;
+import java.util.Set;
 import org.sleuthkit.datamodel.BlackboardArtifact.ARTIFACT_TYPE;
 import org.sleuthkit.datamodel.BlackboardAttribute.ATTRIBUTE_TYPE;
+import org.sleuthkit.datamodel.SleuthkitCase.ObjectInfo;
 
 /**
  * An artifact that has been posted to the blackboard. An artifact is a typed
@@ -38,18 +43,28 @@ import org.sleuthkit.datamodel.BlackboardAttribute.ATTRIBUTE_TYPE;
  * IMPORTANT NOTE: No more than one attribute of a given type should be added to
  * an artifact.
  */
-public class BlackboardArtifact implements SleuthkitVisitableItem {
+public class BlackboardArtifact implements Content {
 
 	private static final ResourceBundle bundle = ResourceBundle.getBundle("org.sleuthkit.datamodel.Bundle");
 	private final long artifactId;
-	private final long objId;
+	private final long sourceObjId;				// refers to objID of parent/source object
+	private final long artifactObjId;			// objId of the artifact in tsk_objects. TBD: replace artifactID with this
+	private final long dataSourceObjId;			// objId of the data source in tsk_objects.
 	private final int artifactTypeId;
 	private final String artifactTypeName;
 	private final String displayName;
-	private final ReviewStatus reviewStatus;
+	private ReviewStatus reviewStatus;
 	private final SleuthkitCase sleuthkitCase;
 	private final List<BlackboardAttribute> attrsCache = new ArrayList<BlackboardAttribute>();
 	private boolean loadedCacheFromDb = false;
+	private Content parent;
+	private String uniquePath;
+
+	private byte[] contentBytes = null;
+
+	private volatile boolean checkedHasChildren;
+	private volatile boolean hasChildren;
+	private volatile int childrenCount;
 
 	/**
 	 * Constructs an artifact that has been posted to the blackboard. An
@@ -60,22 +75,33 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	 *
 	 * @param sleuthkitCase    The SleuthKit case (case database) that contains
 	 *                         the artifact data.
-	 * @param artifactID       The unique id for this artifact.
-	 * @param objID            The unique id of the content with which this
+	 * @param artifactID       The unique id for this artifact
+	 * @param sourceObjId      The unique id of the content with which this
 	 *                         artifact is associated.
+	 * @param artifactObjId    The unique id this artifact, in tsk_objects
+	 * @param dataSourceObjId  Object ID of the datasource where the artifact
+	 *                         was found.
 	 * @param artifactTypeID   The type id of this artifact.
 	 * @param artifactTypeName The type name of this artifact.
 	 * @param displayName      The display name of this artifact.
 	 * @param reviewStatus     The review status of this artifact.
 	 */
-	BlackboardArtifact(SleuthkitCase sleuthkitCase, long artifactID, long objID, int artifactTypeID, String artifactTypeName, String displayName, ReviewStatus reviewStatus) {
+	BlackboardArtifact(SleuthkitCase sleuthkitCase, long artifactID, long sourceObjId, long artifactObjId, long dataSourceObjId, int artifactTypeID, String artifactTypeName, String displayName, ReviewStatus reviewStatus) {
+
 		this.sleuthkitCase = sleuthkitCase;
 		this.artifactId = artifactID;
-		this.objId = objID;
+		this.sourceObjId = sourceObjId;
+		this.artifactObjId = artifactObjId;
 		this.artifactTypeId = artifactTypeID;
+		this.dataSourceObjId = dataSourceObjId;
 		this.artifactTypeName = artifactTypeName;
 		this.displayName = displayName;
 		this.reviewStatus = reviewStatus;
+
+		this.checkedHasChildren = false;
+		this.hasChildren = false;
+		this.childrenCount = -1;
+
 	}
 
 	/**
@@ -88,15 +114,17 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	 * @param sleuthkitCase    The SleuthKit case (case database) that contains
 	 *                         the artifact data.
 	 * @param artifactID       The unique id for this artifact.
-	 * @param objID            The unique id of the content with which this
+	 * @param sourceObjId      The unique id of the content with which this
 	 *                         artifact is associated.
+	 * @param artifactObjID    The unique id this artifact. in tsk_objects
+	 * @param dataSourceObjID  Unique id of the data source.
 	 * @param artifactTypeID   The type id of this artifact.
 	 * @param artifactTypeName The type name of this artifact.
 	 * @param displayName      The display name of this artifact.
 	 * @param reviewStatus     The review status of this artifact.
 	 */
-	BlackboardArtifact(SleuthkitCase sleuthkitCase, long artifactID, long objID, int artifactTypeID, String artifactTypeName, String displayName, ReviewStatus reviewStatus, boolean isNew) {
-		this(sleuthkitCase, artifactID, objID, artifactTypeID, artifactTypeName, displayName, reviewStatus);
+	BlackboardArtifact(SleuthkitCase sleuthkitCase, long artifactID, long sourceObjId, long artifactObjID, long dataSourceObjID, int artifactTypeID, String artifactTypeName, String displayName, ReviewStatus reviewStatus, boolean isNew) {
+		this(sleuthkitCase, artifactID, sourceObjId, artifactObjID, dataSourceObjID, artifactTypeID, artifactTypeName, displayName, reviewStatus);
 		if (isNew) {
 			/*
 			 * If this object represents a newly created artifact, then its
@@ -133,7 +161,16 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	 * @return The object id.
 	 */
 	public long getObjectID() {
-		return this.objId;
+		return this.sourceObjId;
+	}
+
+	/**
+	 * Gets the object id of the data source for this artifact.
+	 *
+	 * @return The data source object id.
+	 */
+	long getDataSourceObjectID() {
+		return this.dataSourceObjId;
 	}
 
 	/**
@@ -171,64 +208,68 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	 * @throws TskCoreException if there is a problem creating the description.
 	 */
 	public String getShortDescription() throws TskCoreException {
-		List<BlackboardAttribute> attrs;
-		attrs = new ArrayList<BlackboardAttribute>();  //only allow the adding of one or two items to keep descirption short
+		BlackboardAttribute attr = null;
+		StringBuilder shortDescription = new StringBuilder("");
 		switch (ARTIFACT_TYPE.fromID(artifactTypeId)) {
 			case TSK_WEB_BOOKMARK:  //web_bookmark, web_cookie, web_download, and web_history are the same attribute for now
 			case TSK_WEB_COOKIE:
 			case TSK_WEB_DOWNLOAD:
 			case TSK_WEB_HISTORY:
-				attrs.add(getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_DOMAIN)));
+				attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_DOMAIN));
 				break;
 			case TSK_KEYWORD_HIT:
-				attrs.add(getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_KEYWORD_PREVIEW)));
+				attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_KEYWORD_PREVIEW));
 				break;
 			case TSK_DEVICE_ATTACHED:
-				attrs.add(getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_DEVICE_ID)));
+				attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_DEVICE_ID));
 				break;
 			case TSK_CONTACT: //contact, message, and calllog are the same attributes for now
 			case TSK_MESSAGE:
 			case TSK_CALLLOG:
-				BlackboardAttribute name;
-				if (((name = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_NAME))) != null) && !name.getDisplayString().isEmpty()) {
-					attrs.add(name);
-				}
-				BlackboardAttribute attr;
-				if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_PHONE_NUMBER))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_FROM))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_TO))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_HOME))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_MOBILE))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_OFFICE))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_EMAIL))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_EMAIL_FROM))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_EMAIL_TO))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_EMAIL_HOME))) != null) {
-					attrs.add(attr);
-				} else if ((attr = getAttribute(new BlackboardAttribute.Type(ATTRIBUTE_TYPE.TSK_EMAIL_OFFICE))) != null) {
-					attrs.add(attr);
+				//get the first of these attributes which exists and is non null
+				final ATTRIBUTE_TYPE[] typesThatCanHaveName = {ATTRIBUTE_TYPE.TSK_NAME,
+					ATTRIBUTE_TYPE.TSK_PHONE_NUMBER,
+					ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_FROM,
+					ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_TO,
+					ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_HOME,
+					ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_MOBILE,
+					ATTRIBUTE_TYPE.TSK_PHONE_NUMBER_OFFICE,
+					ATTRIBUTE_TYPE.TSK_EMAIL,
+					ATTRIBUTE_TYPE.TSK_EMAIL_FROM,
+					ATTRIBUTE_TYPE.TSK_EMAIL_TO,
+					ATTRIBUTE_TYPE.TSK_EMAIL_HOME,
+					ATTRIBUTE_TYPE.TSK_EMAIL_OFFICE}; //in the order we want to use them 
+				for (ATTRIBUTE_TYPE t : typesThatCanHaveName) {
+					attr = getAttribute(new BlackboardAttribute.Type(t));
+					if (attr != null && !attr.getDisplayString().isEmpty()) {
+						break;
+					}
 				}
 				break;
-			default:  //no description by default
+			default:
+				break;
 		}
-		StringBuilder shortDescription = new StringBuilder("");
-		for (int i = 0; i < attrs.size(); i++) {
-			BlackboardAttribute attr = attrs.get(i);
-			String valueToDisplay = attr.getDisplayString();
-			shortDescription.append(attr.getAttributeType().getDisplayName());
-			shortDescription.append(": "); //NON-NLS
-			shortDescription.append(valueToDisplay);
-			if (attrs.size() != i + 1) { //add seperator before next attribute.
-				shortDescription.append("; ");
+		if (attr != null) {
+			shortDescription.append(attr.getAttributeType().getDisplayName()).append(": ").append(attr.getDisplayString());
+		} else {
+			shortDescription.append(getDisplayName());
+		}
+		//get the first of these date attributes which exists and is non null
+		final ATTRIBUTE_TYPE[] typesThatCanHaveDate = {ATTRIBUTE_TYPE.TSK_DATETIME,
+			ATTRIBUTE_TYPE.TSK_DATETIME_SENT,
+			ATTRIBUTE_TYPE.TSK_DATETIME_RCVD,
+			ATTRIBUTE_TYPE.TSK_DATETIME_CREATED,
+			ATTRIBUTE_TYPE.TSK_DATETIME_MODIFIED,
+			ATTRIBUTE_TYPE.TSK_DATETIME_ACCESSED,
+			ATTRIBUTE_TYPE.TSK_DATETIME_START,
+			ATTRIBUTE_TYPE.TSK_DATETIME_END};  //in the order we want to use them 
+		BlackboardAttribute date;
+		for (ATTRIBUTE_TYPE t : typesThatCanHaveDate) {
+			date = getAttribute(new BlackboardAttribute.Type(t));
+			if (date != null && !date.getDisplayString().isEmpty()) {
+				shortDescription.append(" ");
+				shortDescription.append(MessageFormat.format(bundle.getString("BlackboardArtifact.shortDescriptionDate.text"), date.getDisplayString()));  //NON-NLS
+				break;
 			}
 		}
 		return shortDescription.toString();
@@ -244,6 +285,19 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 		return reviewStatus;
 	}
 
+	/**
+	 * Sets the review status of this artifact, i.e., whether it has been
+	 * approved, rejected, or is still waiting for a decision from the user.
+	 *
+	 * @param newStatus new status of the artifact
+	 *
+	 * @throws TskCoreException If an error occurs
+	 */
+	public void setReviewStatus(ReviewStatus newStatus) throws TskCoreException {
+		getSleuthkitCase().setReviewStatus(this, newStatus);
+		reviewStatus = newStatus;
+	}
+	
 	/**
 	 * Adds an attribute to this artifact.
 	 *
@@ -257,8 +311,8 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	 */
 	public void addAttribute(BlackboardAttribute attribute) throws TskCoreException {
 		attribute.setArtifactId(artifactId);
-		attribute.setCaseDatabase(sleuthkitCase);
-		sleuthkitCase.addBlackboardAttribute(attribute, this.artifactTypeId);
+		attribute.setCaseDatabase(getSleuthkitCase());
+		getSleuthkitCase().addBlackboardAttribute(attribute, this.artifactTypeId);
 		attrsCache.add(attribute);
 	}
 
@@ -273,7 +327,7 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	public List<BlackboardAttribute> getAttributes() throws TskCoreException {
 		ArrayList<BlackboardAttribute> attributes;
 		if (false == loadedCacheFromDb) {
-			attributes = sleuthkitCase.getBlackboardAttributes(this);
+			attributes = getSleuthkitCase().getBlackboardAttributes(this);
 			attrsCache.clear();
 			attrsCache.addAll(attributes);
 			loadedCacheFromDb = true;
@@ -322,12 +376,278 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 		}
 		for (BlackboardAttribute attribute : attributes) {
 			attribute.setArtifactId(artifactId);
-			attribute.setCaseDatabase(sleuthkitCase);
+			attribute.setCaseDatabase(getSleuthkitCase());
 		}
-		sleuthkitCase.addBlackboardAttributes(attributes, artifactTypeId);
+		getSleuthkitCase().addBlackboardAttributes(attributes, artifactTypeId);
 		attrsCache.addAll(attributes);
 	}
 
+	/**
+	 * This overiding implementation returns the unique path of the parent. It
+	 * does not include the Artifact name in the unique path.
+	 *
+	 * @throws org.sleuthkit.datamodel.TskCoreException
+	 */
+	@Override
+	public synchronized String getUniquePath() throws TskCoreException {
+
+		// Return the path of the parrent file
+		if (uniquePath == null) {
+			uniquePath = "";
+			Content myParent = getParent();
+			if (myParent != null) {
+				uniquePath = myParent.getUniquePath();
+			}
+		}
+		return uniquePath;
+	}
+
+	@Override
+	public synchronized Content getParent() throws TskCoreException {
+		if (parent == null) {
+			ObjectInfo parentInfo;
+			try {
+				parentInfo = getSleuthkitCase().getParentInfo(this);
+			} catch (TskCoreException ex) {
+				// there is not parent; not an error if we've got a data source
+				return null;
+			}
+			parent = getSleuthkitCase().getContentById(parentInfo.getId());
+		}
+		return parent;
+	}
+
+	/**
+	 * Get all artifacts associated with this content
+	 *
+	 * @return a list of blackboard artifacts
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public ArrayList<BlackboardArtifact> getAllArtifacts() throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return new ArrayList<BlackboardArtifact>();
+	}
+
+	/**
+	 * Get all artifacts associated with this content that have the given type
+	 * name
+	 *
+	 * @param artifactTypeName name of the type to look up
+	 *
+	 * @return a list of blackboard artifacts matching the type
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public ArrayList<BlackboardArtifact> getArtifacts(String artifactTypeName) throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return new ArrayList<BlackboardArtifact>();
+	}
+
+	/**
+	 * Get all artifacts associated with this content that have the given type
+	 * id
+	 *
+	 * @param artifactTypeID type id to look up
+	 *
+	 * @return a list of blackboard artifacts matching the type
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public ArrayList<BlackboardArtifact> getArtifacts(int artifactTypeID) throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return new ArrayList<BlackboardArtifact>();
+	}
+
+	/**
+	 * Get all artifacts associated with this content that have the given type
+	 *
+	 * @param type type to look up
+	 *
+	 * @return a list of blackboard artifacts matching the type
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public ArrayList<BlackboardArtifact> getArtifacts(BlackboardArtifact.ARTIFACT_TYPE type) throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return new ArrayList<BlackboardArtifact>();
+	}
+
+	/**
+	 * Get count of all artifacts associated with this content
+	 *
+	 * @return count of all blackboard artifacts for this content
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public long getAllArtifactsCount() throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return 0;
+	}
+
+	/**
+	 * Get count of all artifacts associated with this content that have the
+	 * given type name
+	 *
+	 * @param artifactTypeName name of the type to look up
+	 *
+	 * @return count of blackboard artifacts matching the type
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public long getArtifactsCount(String artifactTypeName) throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return 0;
+	}
+
+	/**
+	 * Get count of all artifacts associated with this content that have the
+	 * given type id
+	 *
+	 * @param artifactTypeID type id to look up
+	 *
+	 * @return count of blackboard artifacts matching the type
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public long getArtifactsCount(int artifactTypeID) throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return 0;
+	}
+
+	/**
+	 * Get count of all artifacts associated with this content that have the
+	 * given type
+	 *
+	 * @param type type to look up
+	 *
+	 * @return count of blackboard artifacts matching the type
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public long getArtifactsCount(BlackboardArtifact.ARTIFACT_TYPE type) throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return 0;
+	}
+
+	/**
+	 * Return the TSK_GEN_INFO artifact for the file so that individual
+	 * attributes can be added to it. Creates one if it does not already exist.
+	 *
+	 * @return Instance of the TSK_GEN_INFO artifact
+	 *
+	 * @throws TskCoreException
+	 */
+	@Override
+	public BlackboardArtifact getGenInfoArtifact() throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return null;
+	}
+
+	/**
+	 * Return the TSK_GEN_INFO artifact for the file so that individual
+	 * attributes can be added to it. If one does not create, behavior depends
+	 * on the create argument.
+	 *
+	 * @param create If true, an artifact will be created if it does not already
+	 *               exist.
+	 *
+	 * @return Instance of the TSK_GEN_INFO artifact or null if artifact does
+	 *         not already exist and create was set to false
+	 *
+	 * @throws TskCoreException
+	 */
+	@Override
+	public BlackboardArtifact getGenInfoArtifact(boolean create) throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		if (create) {
+			throw new TskCoreException("Artifacts of artifacts are not supported.");
+		}
+
+		return null;
+	}
+
+	/**
+	 * Return attributes of a given type from TSK_GEN_INFO.
+	 *
+	 * @param attr_type Attribute type to find inside of the TSK_GEN_INFO
+	 *                  artifact.
+	 *
+	 * @return Attributes
+	 *
+	 * @throws org.sleuthkit.datamodel.TskCoreException
+	 */
+	@Override
+	public ArrayList<BlackboardAttribute> getGenInfoAttributes(BlackboardAttribute.ATTRIBUTE_TYPE attr_type) throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return new ArrayList<BlackboardAttribute>();
+	}
+
+	/**
+	 * Get the names of all the hashsets that this content is in.
+	 *
+	 * @return the names of the hashsets that this content is in
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public Set<String> getHashSetNames() throws TskCoreException {
+		// Currently we don't have any artifacts derived from an artifact.
+		return new HashSet<String>();
+	}
+
+	/**
+	 * Create and add an artifact associated with this content to the blackboard
+	 *
+	 * @param artifactTypeID id of the artifact type (if the id doesn't already
+	 *                       exist an exception will be thrown)
+	 *
+	 * @return the blackboard artifact created (the artifact type id can be
+	 *         looked up from this)
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public BlackboardArtifact newArtifact(int artifactTypeID) throws TskCoreException {
+		throw new TskCoreException("Cannot create artifact of an artifact. Not supported.");
+	}
+
+	/**
+	 * Create and add an artifact associated with this content to the blackboard
+	 *
+	 * @param type artifact enum type
+	 *
+	 * @return the blackboard artifact created (the artifact type id can be
+	 *         looked up from this)
+	 *
+	 * @throws TskCoreException if critical error occurred within tsk core
+	 */
+	@Override
+	public BlackboardArtifact newArtifact(BlackboardArtifact.ARTIFACT_TYPE type) throws TskCoreException {
+		throw new TskCoreException("Cannot create artifact of an artifact. Not supported.");
+	}
+
+	/**
+	 * Accepts a Sleuthkit item visitor (Visitor design pattern).
+	 *
+	 * @param visitor A SleuthkitItemVisitor supplying an algorithm to run using
+	 *                this derived file as input.
+	 *
+	 * @return The output of the algorithm.
+	 */
+	@Override
+	public <T> T accept(ContentVisitor<T> v) {
+		return v.visit(this);
+	}
+
 	/**
 	 * Tests this artifact for equality with another object.
 	 *
@@ -366,7 +686,7 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	 */
 	@Override
 	public String toString() {
-		return "BlackboardArtifact{" + "artifactID=" + artifactId + ", objID=" + objId + ", artifactTypeID=" + artifactTypeId + ", artifactTypeName=" + artifactTypeName + ", displayName=" + displayName + ", Case=" + sleuthkitCase + '}'; //NON-NLS
+		return "BlackboardArtifact{" + "artifactID=" + artifactId + ", objID=" + getObjectID() + ", artifactObjID=" + artifactObjId + ", artifactTypeID=" + artifactTypeId + ", artifactTypeName=" + artifactTypeName + ", displayName=" + displayName + ", Case=" + getSleuthkitCase() + '}'; //NON-NLS
 	}
 
 	/**
@@ -384,6 +704,118 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 		return visitor.visit(this);
 	}
 
+	/**
+	 * Get the (reported) size of the content object. Artifact content is a
+	 * string dump of all its attributes.
+	 *
+	 * @return size of the content in bytes
+	 */
+	@Override
+	public long getSize() {
+
+		if (contentBytes == null) {
+			try {
+				loadArtifactContent();
+			} catch (TskCoreException ex) {
+				return 0;
+			}
+		}
+
+		return contentBytes.length;
+	}
+
+	/**
+	 * Close the Content object.
+	 */
+	@Override
+	public void close() {
+		contentBytes = null;
+	}
+
+	/**
+	 * Reads content data for this artifact Artifact content is a string dump of
+	 * all its attributes.
+	 *
+	 * @param buf    a character array of data (in bytes) to copy read data to
+	 * @param offset byte offset in the content to start reading from
+	 * @param len    number of bytes to read into buf.
+	 *
+	 * @return num of bytes read, or -1 on error
+	 *
+	 * @throws TskCoreException if critical error occurred during read in the
+	 *                          tsk core
+	 */
+	@Override
+	public final int read(byte[] buf, long offset, long len) throws TskCoreException {
+
+		if (contentBytes == null) {
+			loadArtifactContent();
+		}
+
+		if (0 == contentBytes.length) {
+			return 0;
+		}
+
+		// Copy bytes
+		long readLen = Math.min(contentBytes.length - offset, len);
+		System.arraycopy(contentBytes, 0, buf, 0, (int) readLen);
+
+		return (int) readLen;
+	}
+
+	@Override
+	public String getName() {
+		return this.displayName + getArtifactID();
+	}
+
+	@Override
+	public Content getDataSource() throws TskCoreException {
+		Content myParent = getParent();
+		if (myParent == null) {
+			return null;
+		}
+
+		return myParent.getDataSource();
+	}
+
+	/**
+	 * Load and save the content for the artifact. Artifact content is a string
+	 * dump of all its attributes.
+	 *
+	 * @throws TskCoreException if critical error occurred during read
+	 */
+	private void loadArtifactContent() throws TskCoreException {
+		StringBuilder artifactContents = new StringBuilder();
+
+		Content dataSource = null;
+		try {
+			dataSource = getDataSource();
+		} catch (TskCoreException ex) {
+			throw new TskCoreException("Unable to get datasource for artifact: " + this.toString(), ex);
+		}
+		if (dataSource == null) {
+			throw new TskCoreException("Datasource was null for artifact: " + this.toString());
+		}
+
+		try {
+			for (BlackboardAttribute attribute : getAttributes()) {
+				artifactContents.append(attribute.getAttributeType().getDisplayName());
+				artifactContents.append(" : ");
+				artifactContents.append(attribute.getDisplayString());
+				artifactContents.append(System.lineSeparator());
+			}
+		} catch (TskCoreException ex) {
+			throw new TskCoreException("Unable to get attributes for artifact: " + this.toString(), ex);
+		}
+
+		try {
+			contentBytes = artifactContents.toString().getBytes("UTF-8");
+		} catch (UnsupportedEncodingException ex) {
+			throw new TskCoreException("Failed to convert artifact string to bytes for artifact: " + this.toString(), ex);
+		}
+
+	}
+
 	/**
 	 * An artifact type.
 	 */
@@ -703,7 +1135,12 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 		 * An account.
 		 */
 		TSK_ACCOUNT(39, "TSK_ACCOUNT", //NON-NLS
-				bundle.getString("BlackboardArtifact.tskAccount.text"));
+				bundle.getString("BlackboardArtifact.tskAccount.text")),
+		/**
+		 * An encrypted file.
+		 */
+		TSK_ENCRYPTION_SUSPECTED(40, "TSK_ENCRYPTION_SUSPECTED", //NON-NLS
+				bundle.getString("BlackboardArtifact.tskEncryptionSuspected.text"));
 
 		private final String label;
 		private final int typeId;
@@ -886,6 +1323,8 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	 * @param artifactID       The unique id for this artifact.
 	 * @param objID            The unique id of the content with which this
 	 *                         artifact is associated.
+	 * @param artifactObjID	   The unique id of the artifact, in tsk_objects
+	 * @param dataSourceObjId  The id of the data source
 	 * @param artifactTypeID   The type id of this artifact.
 	 * @param artifactTypeName The type name of this artifact.
 	 * @param displayName      The display name of this artifact.
@@ -894,8 +1333,8 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	 * String, String, ReviewStatus) instead.
 	 */
 	@Deprecated
-	protected BlackboardArtifact(SleuthkitCase sleuthkitCase, long artifactID, long objID, int artifactTypeID, String artifactTypeName, String displayName) {
-		this(sleuthkitCase, artifactID, objID, artifactTypeID, artifactTypeName, displayName, ReviewStatus.UNDECIDED);
+	protected BlackboardArtifact(SleuthkitCase sleuthkitCase, long artifactID, long objID, long artifactObjID, long dataSourceObjId, int artifactTypeID, String artifactTypeName, String displayName) {
+		this(sleuthkitCase, artifactID, objID, artifactObjID, dataSourceObjId, artifactTypeID, artifactTypeName, displayName, ReviewStatus.UNDECIDED);
 	}
 
 	/**
@@ -915,7 +1354,7 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 	@Deprecated
 	public List<BlackboardAttribute> getAttributes(final BlackboardAttribute.ATTRIBUTE_TYPE attributeType) throws TskCoreException {
 		if (loadedCacheFromDb == false) {
-			List<BlackboardAttribute> attrs = sleuthkitCase.getBlackboardAttributes(this);
+			List<BlackboardAttribute> attrs = getSleuthkitCase().getBlackboardAttributes(this);
 			attrsCache.clear();
 			attrsCache.addAll(attrs);
 			loadedCacheFromDb = true;
@@ -929,4 +1368,70 @@ public class BlackboardArtifact implements SleuthkitVisitableItem {
 		return filteredAttributes;
 	}
 
+	@Override
+	public long getId() {
+		return this.artifactObjId;
+	}
+
+	/**
+	 * Gets the object ids of children of this artifact, if any
+	 *
+	 * @return A list of the object ids of children.
+	 *
+	 * @throws TskCoreException if there was an error querying the case
+	 *                          database.
+	 */
+	@Override
+	public List<Long> getChildrenIds() throws TskCoreException {
+		List<Long> childrenIDs = new ArrayList<Long>();
+		childrenIDs.addAll(getSleuthkitCase().getAbstractFileChildrenIds(this));
+		childrenIDs.addAll(getSleuthkitCase().getBlackboardArtifactChildrenIds(this));
+
+		return childrenIDs;
+	}
+
+	@Override
+	public int getChildrenCount() throws TskCoreException {
+		if (childrenCount != -1) {
+			return childrenCount;
+		}
+
+		childrenCount = this.getSleuthkitCase().getContentChildrenCount(this);
+
+		hasChildren = childrenCount > 0;
+		checkedHasChildren = true;
+
+		return childrenCount;
+	}
+
+	@Override
+	public boolean hasChildren() throws TskCoreException {
+		if (checkedHasChildren == true) {
+			return hasChildren;
+		}
+
+		childrenCount = this.getSleuthkitCase().getContentChildrenCount(this);
+
+		hasChildren = childrenCount > 0;
+		checkedHasChildren = true;
+
+		return hasChildren;
+	}
+
+	/**
+	 * Get all children of this artifact, if any.
+	 *
+	 * @return A list of the children.
+	 *
+	 * @throws TskCoreException if there was an error querying the case
+	 *                          database.
+	 */
+	@Override
+	public List<Content> getChildren() throws TskCoreException {
+		List<Content> children = new ArrayList<Content>();
+		children.addAll(getSleuthkitCase().getAbstractFileChildren(this));
+		children.addAll(getSleuthkitCase().getBlackboardArtifactChildren(this));
+
+		return children;
+	}
 }
