@@ -116,7 +116,7 @@ public interface SleuthkitItemVisitor<T> {
 	T visit(LayoutFile lf);
 
 	/**
-	 * Act on (visit) a LayoutDirectory content object
+	 * Act on (visit) a VirtualDirectory content object
 	 *
 	 * @param ld layout dir to visit / act on
 	 *
@@ -124,6 +124,15 @@ public interface SleuthkitItemVisitor<T> {
 	 */
 	T visit(VirtualDirectory ld);
 
+	/**
+	 * Act on (visit) a LocalDirectory content object
+	 *
+	 * @param ld layout dir to visit / act on
+	 *
+	 * @return result of the visit
+	 */
+	T visit(LocalDirectory ld);
+
 	/**
 	 * Act on (visit) a DerivedFile content object
 	 *
@@ -214,6 +223,11 @@ public interface SleuthkitItemVisitor<T> {
 			return defaultVisit(vd);
 		}
 
+		@Override
+		public T visit(LocalDirectory ld) {
+			return defaultVisit(ld);
+		}
+
 		@Override
 		public T visit(DerivedFile df) {
 			return defaultVisit(df);
