@@ -37,6 +37,12 @@ TskDbPostgreSQL::TskDbPostgreSQL(const TSK_TCHAR * a_dbFilePath, bool a_blkMapFl
     conn = NULL;
     wcsncpy(m_dBName, a_dbFilePath, MAX_CONN_INFO_FIELD_LENGTH - 1);
     m_blkMapFlag = a_blkMapFlag;
+
+	strcpy(userName, "");
+	strcpy(password, "");
+	strcpy(hostNameOrIpAddr, "");
+	strcpy(hostPort, "");
+
 }
 
 TskDbPostgreSQL::~TskDbPostgreSQL()
@@ -204,9 +210,7 @@ int TskDbPostgreSQL::open(bool createDbFlag)
     if (createDbFlag) {
         // initialize TSK tables
         if (initialize()) {
-            tsk_error_reset();
-            tsk_error_set_errno(TSK_ERR_AUTO_DB);
-            tsk_error_set_errstr("TskDbPostgreSQL::open: Couldn't initialize database %S", m_dBName);
+            tsk_error_set_errstr2("TskDbPostgreSQL::open: Couldn't initialize database %S", m_dBName);
             close();    // close connection to database
             return -1;
         }
@@ -303,7 +307,7 @@ int TskDbPostgreSQL::attempt_exec(const char *sql, const char *errfmt)
 */
 int TskDbPostgreSQL::isEscapedStringValid(const char *sql_str, const char *orig_str, const char *errfmt){
 
-    if (!sql_str){
+    if (sql_str == NULL){
         tsk_error_reset();
         tsk_error_set_errno(TSK_ERR_AUTO_DB);
         char * str = PQerrorMessage(conn);
@@ -491,11 +495,11 @@ void TskDbPostgreSQL::removeNonUtf8(char* newStr, int newStrMaxSize, const char*
 int TskDbPostgreSQL::initialize() { 
 
     char foo[1024];
-    if (attempt_exec("CREATE TABLE tsk_db_info (schema_ver INTEGER, tsk_ver INTEGER);","Error creating tsk_db_info table: %s\n")) {
+    if (attempt_exec("CREATE TABLE tsk_db_info (schema_ver INTEGER, tsk_ver INTEGER, schema_minor_ver INTEGER);","Error creating tsk_db_info table: %s\n")) {
         return 1;
     }
 
-    snprintf(foo, 1024, "INSERT INTO tsk_db_info (schema_ver, tsk_ver) VALUES (%d, %d);", TSK_SCHEMA_VER, TSK_VERSION_NUM);
+    snprintf(foo, 1024, "INSERT INTO tsk_db_info (schema_ver, tsk_ver, schema_minor_ver) VALUES (%d, %d,%d);", TSK_SCHEMA_VER, TSK_VERSION_NUM, TSK_SCHEMA_MINOR_VER);
     if (attempt_exec(foo, "Error adding data to tsk_db_info table: %s\n")) {
         return 1;
     }
@@ -524,7 +528,7 @@ int TskDbPostgreSQL::initialize() {
         "Error creating tsk_fs_info table: %s\n")
         ||
         attempt_exec
-        ("CREATE TABLE tsk_files (obj_id BIGSERIAL PRIMARY KEY, fs_obj_id BIGINT, data_source_obj_id BIGINT NOT NULL, attr_type INTEGER, attr_id INTEGER, name TEXT NOT NULL, meta_addr BIGINT, meta_seq BIGINT, type INTEGER, has_layout INTEGER, has_path INTEGER, dir_type INTEGER, meta_type INTEGER, dir_flags INTEGER, meta_flags INTEGER, size BIGINT, ctime BIGINT, crtime BIGINT, atime BIGINT, mtime BIGINT, mode INTEGER, uid INTEGER, gid INTEGER, md5 TEXT, known INTEGER, parent_path TEXT, mime_type TEXT, "
+        ("CREATE TABLE tsk_files (obj_id BIGSERIAL PRIMARY KEY, fs_obj_id BIGINT, data_source_obj_id BIGINT NOT NULL, attr_type INTEGER, attr_id INTEGER, name TEXT NOT NULL, meta_addr BIGINT, meta_seq BIGINT, type INTEGER, has_layout INTEGER, has_path INTEGER, dir_type INTEGER, meta_type INTEGER, dir_flags INTEGER, meta_flags INTEGER, size BIGINT, ctime BIGINT, crtime BIGINT, atime BIGINT, mtime BIGINT, mode INTEGER, uid INTEGER, gid INTEGER, md5 TEXT, known INTEGER, parent_path TEXT, mime_type TEXT, extension TEXT, "
         "FOREIGN KEY(obj_id) REFERENCES tsk_objects(obj_id), FOREIGN KEY(fs_obj_id) REFERENCES tsk_fs_info(obj_id), FOREIGN KEY(data_source_obj_id) REFERENCES data_source_info(obj_id));",
         "Error creating tsk_files table: %s\n")
         ||
@@ -539,7 +543,7 @@ int TskDbPostgreSQL::initialize() {
         ||
         attempt_exec("CREATE TABLE tsk_files_derived_method (derived_id BIGSERIAL PRIMARY KEY, tool_name TEXT NOT NULL, tool_version TEXT NOT NULL, other TEXT)","Error creating tsk_files_derived_method table: %s\n")
         ||
-        attempt_exec("CREATE TABLE tag_names (tag_name_id BIGSERIAL PRIMARY KEY, display_name TEXT UNIQUE, description TEXT NOT NULL, color TEXT NOT NULL)","Error creating tag_names table: %s\n")
+        attempt_exec("CREATE TABLE tag_names (tag_name_id BIGSERIAL PRIMARY KEY, display_name TEXT UNIQUE, description TEXT NOT NULL, color TEXT NOT NULL, knownStatus INTEGER NOT NULL)","Error creating tag_names table: %s\n")
         ||
         attempt_exec("CREATE TABLE content_tags (tag_id BIGSERIAL PRIMARY KEY, obj_id BIGINT NOT NULL, tag_name_id BIGINT NOT NULL, comment TEXT NOT NULL, begin_byte_offset BIGINT NOT NULL, end_byte_offset BIGINT NOT NULL, "
         "FOREIGN KEY(obj_id) REFERENCES tsk_objects(obj_id), FOREIGN KEY(tag_name_id) REFERENCES tag_names(tag_name_id))",
@@ -556,9 +560,13 @@ int TskDbPostgreSQL::initialize() {
         ||
         attempt_exec("CREATE TABLE blackboard_artifacts (artifact_id BIGSERIAL PRIMARY KEY, "
 		"obj_id BIGINT NOT NULL, "
+		"artifact_obj_id BIGINT NOT NULL, "
+		"data_source_obj_id BIGINT NOT NULL, "
 		"artifact_type_id BIGINT NOT NULL, "
 		"review_status_id INTEGER NOT NULL, "
         "FOREIGN KEY(obj_id) REFERENCES tsk_objects(obj_id), "
+		"FOREIGN KEY(artifact_obj_id) REFERENCES tsk_objects(obj_id), "
+		"FOREIGN KEY(data_source_obj_id) REFERENCES tsk_objects(obj_id), "
 		"FOREIGN KEY(artifact_type_id) REFERENCES blackboard_artifact_types(artifact_type_id), "
 		"FOREIGN KEY(review_status_id) REFERENCES review_statuses(review_status_id))",
         "Error creating blackboard_artifact table: %s\n")
@@ -605,8 +613,19 @@ int TskDbPostgreSQL::initialize() {
         "Error creating ingest_job_modules table: %s\n")
         ||
         attempt_exec
-        ("CREATE TABLE reports (report_id BIGSERIAL PRIMARY KEY, path TEXT NOT NULL, crtime INTEGER NOT NULL, src_module_name TEXT NOT NULL, report_name TEXT NOT NULL)","Error creating reports table: %s\n")) {
-            return 1;
+        ("CREATE TABLE reports (report_id BIGSERIAL PRIMARY KEY, path TEXT NOT NULL, crtime INTEGER NOT NULL, src_module_name TEXT NOT NULL, report_name TEXT NOT NULL)","Error creating reports table: %s\n")
+		||
+		attempt_exec
+		("CREATE TABLE account_types (account_type_id BIGSERIAL PRIMARY KEY, type_name TEXT UNIQUE NOT NULL, display_name TEXT NOT NULL)", 
+		"Error creating account_types table: %s\n")     
+		||
+		attempt_exec
+		("CREATE TABLE accounts (account_id BIGSERIAL PRIMARY KEY, account_type_id INTEGER NOT NULL, account_unique_identifier TEXT NOT NULL,  UNIQUE(account_type_id, account_unique_identifier) , FOREIGN KEY(account_type_id) REFERENCES account_types(account_type_id))",
+		"Error creating accounts table: %s\n") ||
+		attempt_exec
+		("CREATE TABLE account_relationships  (relationship_id BIGSERIAL PRIMARY KEY, account1_id INTEGER NOT NULL, account2_id INTEGER NOT NULL, relationship_source_obj_id INTEGER NOT NULL, date_time BIGINT, relationship_type INTEGER NOT NULL, data_source_obj_id INTEGER NOT NULL, UNIQUE(account1_id, account2_id, relationship_source_obj_id), FOREIGN KEY(account1_id) REFERENCES accounts(account_id), FOREIGN KEY(account2_id) REFERENCES accounts(account_id), FOREIGN KEY(relationship_source_obj_id) REFERENCES tsk_objects(obj_id), FOREIGN KEY(data_source_obj_id) REFERENCES tsk_objects(obj_id))",
+		"Error creating relationships table: %s\n")	 ){
+			return 1;
     }
 
     if (m_blkMapFlag) {
@@ -627,27 +646,40 @@ int TskDbPostgreSQL::initialize() {
 * Create indexes for the columns that are not primary keys and that we query on. 
 * @returns 1 on error, 0 on success
 */
-int TskDbPostgreSQL::createIndexes()
-{
-    return
-        // tsk_objects index
-        attempt_exec("CREATE INDEX parObjId ON tsk_objects(par_obj_id);",
-        "Error creating tsk_objects index on par_obj_id: %s\n") ||
-        // file layout index
-        attempt_exec("CREATE INDEX layout_objID ON tsk_file_layout(obj_id);",
-        "Error creating layout_objID index on tsk_file_layout: %s\n") ||
-        // blackboard indexes
-        attempt_exec("CREATE INDEX artifact_objID ON blackboard_artifacts(obj_id);",
-        "Error creating artifact_objID index on blackboard_artifacts: %s\n") ||
-        attempt_exec("CREATE INDEX artifact_typeID ON blackboard_artifacts(artifact_type_id);",
-        "Error creating artifact_objID index on blackboard_artifacts: %s\n") ||
-        attempt_exec("CREATE INDEX attrsArtifactID ON blackboard_attributes(artifact_id);",
-        "Error creating artifact_id index on blackboard_attributes: %s\n") ||
-		attempt_exec("CREATE INDEX mime_type ON tsk_files(dir_type,mime_type,type);",
-		"Error creating mime_type index on tsk_files: %s\n");
-    /*attempt_exec("CREATE INDEX attribute_artifactTypeId ON blackboard_attributes(artifact_type_id);",
-    "Error creating artifact_type_id index on blackboard_attributes: %s\n");
-    */
+int TskDbPostgreSQL::createIndexes() {
+	return
+		// tsk_objects index
+		attempt_exec("CREATE INDEX parObjId ON tsk_objects(par_obj_id);",
+			"Error creating tsk_objects index on par_obj_id: %s\n") ||
+		// file layout index
+		attempt_exec("CREATE INDEX layout_objID ON tsk_file_layout(obj_id);",
+			"Error creating layout_objID index on tsk_file_layout: %s\n") ||
+		// blackboard indexes
+		attempt_exec("CREATE INDEX artifact_objID ON blackboard_artifacts(obj_id);",
+			"Error creating artifact_objID index on blackboard_artifacts: %s\n") ||
+		attempt_exec("CREATE INDEX artifact_artifact_objID ON blackboard_artifacts(artifact_obj_id);",
+			"Error creating artifact_artifact_objID index on blackboard_artifacts: %s\n") ||
+		attempt_exec("CREATE INDEX artifact_typeID ON blackboard_artifacts(artifact_type_id);",
+			"Error creating artifact_objID index on blackboard_artifacts: %s\n") ||
+		attempt_exec("CREATE INDEX attrsArtifactID ON blackboard_attributes(artifact_id);",
+			"Error creating artifact_id index on blackboard_attributes: %s\n") ||
+		//file type indexes
+		attempt_exec("CREATE INDEX mime_type ON tsk_files(dir_type,mime_type,type);", //mime type
+			"Error creating mime_type index on tsk_files: %s\n") ||
+		attempt_exec("CREATE INDEX file_extension ON tsk_files(extension);",  //file extenssion
+			"Error creating file_extension index on tsk_files: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_account1  ON account_relationships(account1_id);",
+			"Error creating relationships_account1 index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_account2  ON account_relationships(account2_id);",
+			"Error creating relationships_account2 index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_relationship_source_obj_id  ON account_relationships(relationship_source_obj_id);",
+			"Error creating relationships_relationship_source_obj_id index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_date_time  ON account_relationships(date_time);",
+			"Error creating relationships_date_time index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_relationship_type ON account_relationships(relationship_type);",
+			"Error creating relationships_relationship_type index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_data_source_obj_id  ON account_relationships(data_source_obj_id);",
+			"Error creating relationships_data_source_obj_id index on account_relationships: %s\n");
 }
 
 
@@ -891,8 +923,9 @@ int TskDbPostgreSQL::addFsFile(TSK_FS_FILE * fs_file,
 {
     int64_t parObjId = 0;
 
-    if (fs_file->name == NULL)
+    if (fs_file->name == NULL) {
         return 0;
+    }
 
     // Find the object id for the parent folder.
 
@@ -974,6 +1007,9 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
 
     strncpy(name, fs_file->name->name, nlen);
 
+	char extension[24] = "";
+	extractExtension(name, extension);
+
     // Add the attribute name
     if (attr_nlen > 0) {
         strncat(name, ":", nlen-strlen(name));
@@ -985,7 +1021,7 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
     size_t path_len = strlen(path) + 2;
     char *escaped_path;
     if ((escaped_path = (char *) tsk_malloc(path_len)) == NULL) { 
-        free(name);
+		free(name);
         return 1;
     }
 
@@ -1015,16 +1051,21 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
     // replace all non-UTF8 characters
     tsk_cleanupUTF8(name, '^');
     tsk_cleanupUTF8(escaped_path, '^');
+	tsk_cleanupUTF8(extension, '^');
 
     // escape strings for use within an SQL command
     char *name_sql = PQescapeLiteral(conn, name, strlen(name));
     char *escaped_path_sql = PQescapeLiteral(conn, escaped_path, strlen(escaped_path));
+	char *extension_sql = PQescapeLiteral(conn, extension, strlen(extension));
     if (!isEscapedStringValid(name_sql, name, "TskDbPostgreSQL::addFile: Unable to escape file name string: %s\n") 
-        || !isEscapedStringValid(escaped_path_sql, escaped_path, "TskDbPostgreSQL::addFile: Unable to escape path string: %s\n")) {
-            free(name);
+        || !isEscapedStringValid(escaped_path_sql, escaped_path, "TskDbPostgreSQL::addFile: Unable to escape path string: %s\n")
+		|| !isEscapedStringValid(extension_sql, extension, "TskDbPostgreSQL::addFile: Unable to escape extension string: %s\n")
+		) {
+			free(name);
             free(escaped_path);
             PQfreemem(name_sql);
             PQfreemem(escaped_path_sql);
+			PQfreemem(extension_sql);
             return 1;
     }
 
@@ -1032,7 +1073,7 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
     zSQL_fixed[2047] = '\0';
     char *zSQL_dynamic = NULL; // Only used if the query does not fit in the fixed length buffer
     char *zSQL = zSQL_fixed;
-    int bufLen = 2048;
+    size_t bufLen = 2048;
 
     // Check if the path may be too long. The rest of the query should take up far less than 500 bytes.
     if (strlen(name_sql) + strlen(escaped_path_sql) + 500 > bufLen) {
@@ -1041,17 +1082,18 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
         // The same buffer will be used for the slack file entry.
         bufLen = strlen(escaped_path_sql) + strlen(name_sql) + 500;
         if ((zSQL_dynamic = (char *)tsk_malloc(bufLen)) == NULL) {
-            free(name);
+			free(name);
             free(escaped_path);
             PQfreemem(escaped_path_sql);
             PQfreemem(name_sql);
+			PQfreemem(extension_sql);
             return 1;
         }
         zSQL_dynamic[bufLen - 1] = '\0';
         zSQL = zSQL_dynamic;
     }
 
-    if (0 > snprintf(zSQL, bufLen - 1, "INSERT INTO tsk_files (fs_obj_id, obj_id, data_source_obj_id, type, attr_type, attr_id, name, meta_addr, meta_seq, dir_type, meta_type, dir_flags, meta_flags, size, crtime, ctime, atime, mtime, mode, gid, uid, md5, known, parent_path) "
+    if (0 > snprintf(zSQL, bufLen - 1, "INSERT INTO tsk_files (fs_obj_id, obj_id, data_source_obj_id, type, attr_type, attr_id, name, meta_addr, meta_seq, dir_type, meta_type, dir_flags, meta_flags, size, crtime, ctime, atime, mtime, mode, gid, uid, md5, known, parent_path,extension) "
         "VALUES ("
         "%" PRId64 ",%" PRId64 ","
         "%" PRId64 ","
@@ -1062,7 +1104,7 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
         "%" PRIuOFF ","
         "%llu,%llu,%llu,%llu,"
         "%d,%d,%d,%s,%d,"
-        "%s)",
+        "%s,%s)",
         fsObjId, objId,
         dataSourceObjId,
         TSK_DB_FILES_TYPE_FS,
@@ -1071,8 +1113,8 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
         fs_file->name->type, meta_type, fs_file->name->flags, meta_flags,
         size,
         (unsigned long long)crtime, (unsigned long long)ctime, (unsigned long long) atime, (unsigned long long) mtime,
-        meta_mode, gid, uid, NULL, known,
-        escaped_path_sql)) {
+        meta_mode, gid, uid, md5TextPtr, known,
+        escaped_path_sql, extension_sql)) {
 
             tsk_error_reset();
             tsk_error_set_errno(TSK_ERR_AUTO_DB);
@@ -1084,14 +1126,16 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
             free(escaped_path);
             PQfreemem(name_sql);
             PQfreemem(escaped_path_sql);
+			PQfreemem(extension_sql);
             return 1;
     }
 
     if (attempt_exec(zSQL, "TskDbPostgreSQL::addFile: Error adding data to tsk_files table: %s\n")) {
-        free(name);
+		free(name);
         free(escaped_path);
         PQfreemem(name_sql);
         PQfreemem(escaped_path_sql);
+		PQfreemem(extension_sql);
         if (zSQL_dynamic != NULL) {
             free(zSQL_dynamic);
         }
@@ -1099,7 +1143,7 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
     }
 
     //if dir, update parent id cache (do this before objId may be changed creating the slack file)
-    if (meta_type == TSK_FS_META_TYPE_DIR) {
+    if (TSK_FS_IS_DIR_META(meta_type)){
         std::string fullPath = std::string(path) + fs_file->name->name;
         storeObjId(fsObjId, fs_file, fullPath.c_str(), objId);
     }
@@ -1116,17 +1160,28 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
            && (! (fs_file->meta->flags & TSK_FS_META_FLAG_COMP))
            && (fs_attr->flags & TSK_FS_ATTR_NONRES) 
            && (fs_attr->nrd.allocsize >  fs_attr->nrd.initsize)){
-        strncat(name, "-slack", 6);
-        name_sql = PQescapeLiteral(conn, name, strlen(name));
+		strncat(name, "-slack", 6);
+		PQfreemem(name_sql);
+		name_sql = PQescapeLiteral(conn, name, strlen(name));
+		if (strlen(extension) > 0) { //if there was an extension, add "-slack" and escape it again.
+			strncat(extension, "-slack", 6);
+			PQfreemem(extension_sql);
+			extension_sql = PQescapeLiteral(conn, extension, strlen(extension));
+		}
+  
+	
         TSK_OFF_T slackSize = fs_attr->nrd.allocsize - fs_attr->nrd.initsize;
 
         if (addObject(TSK_DB_OBJECT_TYPE_FILE, parObjId, objId)) {
-            free(name);
+			free(name);
             free(escaped_path);
+			PQfreemem(name_sql);
+			PQfreemem(escaped_path_sql);
+			PQfreemem(extension_sql);
             return 1;
         }
 
-        if (0 > snprintf(zSQL, bufLen - 1, "INSERT INTO tsk_files (fs_obj_id, obj_id, data_source_obj_id, type, attr_type, attr_id, name, meta_addr, meta_seq, dir_type, meta_type, dir_flags, meta_flags, size, crtime, ctime, atime, mtime, mode, gid, uid, md5, known, parent_path) "
+        if (0 > snprintf(zSQL, bufLen - 1, "INSERT INTO tsk_files (fs_obj_id, obj_id, data_source_obj_id, type, attr_type, attr_id, name, meta_addr, meta_seq, dir_type, meta_type, dir_flags, meta_flags, size, crtime, ctime, atime, mtime, mode, gid, uid, md5, known, parent_path, extension) "
             "VALUES ("
             "%" PRId64 ",%" PRId64 ","
             "%" PRId64 ","
@@ -1136,8 +1191,8 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
             "%d,%d,%d,%d,"
             "%" PRIuOFF ","
             "%llu,%llu,%llu,%llu,"
-            "%d,%d,%d,%s,%d,"
-            "%s)",
+            "%d,%d,%d,NULL,%d,"
+            "%s, %s)",
             fsObjId, objId,
             dataSourceObjId,
             TSK_DB_FILES_TYPE_SLACK,
@@ -1146,16 +1201,17 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
             TSK_FS_NAME_TYPE_REG, TSK_FS_META_TYPE_REG, fs_file->name->flags, meta_flags,
             slackSize, 
             (unsigned long long)crtime, (unsigned long long)ctime,(unsigned long long) atime,(unsigned long long) mtime, 
-            meta_mode, gid, uid, NULL, known,
-            escaped_path_sql)) {
+            meta_mode, gid, uid, known,
+            escaped_path_sql,extension_sql)) {
 
                 tsk_error_reset();
                 tsk_error_set_errno(TSK_ERR_AUTO_DB);
                 tsk_error_set_errstr("Error inserting slack file with object ID for: %" PRId64, objId);
-                free(name);
+				free(name);
                 free(escaped_path);
                 PQfreemem(name_sql);
                 PQfreemem(escaped_path_sql);
+				PQfreemem(extension_sql);
                 if (zSQL_dynamic != NULL) {
                     free(zSQL_dynamic);
                 }
@@ -1163,10 +1219,11 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
         }
 
         if (attempt_exec(zSQL, "TskDbPostgreSQL::addFile: Error adding data to tsk_files table: %s\n")) {
-            free(name);
+			free(name);
             free(escaped_path);
             PQfreemem(name_sql);
-            PQfreemem(escaped_path_sql);
+            PQfreemem(escaped_path_sql);	
+			PQfreemem(extension_sql);
             if (zSQL_dynamic != NULL) {
                 free(zSQL_dynamic);
             }
@@ -1183,6 +1240,7 @@ int TskDbPostgreSQL::addFile(TSK_FS_FILE * fs_file, const TSK_FS_ATTR * fs_attr,
     free(escaped_path);
     PQfreemem(name_sql);
     PQfreemem(escaped_path_sql);
+	PQfreemem(extension_sql);
     return 0;
 }
 
@@ -1247,7 +1305,7 @@ int64_t TskDbPostgreSQL::findParObjId(const TSK_FS_FILE * fs_file, const char *p
     zSQL_fixed[1023] = '\0';
     char *zSQL_dynamic = NULL; // Only used if the query does not fit in the fixed length buffer
     char *zSQL = zSQL_fixed;
-    int bufLen = 1024;
+    size_t bufLen = 1024;
 
     // Check if the path may be too long
     if (strlen(escaped_parent_name_sql) + strlen(escaped_path_sql) + 200 > bufLen) {
@@ -1561,7 +1619,7 @@ typedef struct _checkFileLayoutRangeOverlap{
     const vector<TSK_DB_FILE_LAYOUT_RANGE> & ranges;
     bool hasOverlap;
 
-    _checkFileLayoutRangeOverlap(const vector<TSK_DB_FILE_LAYOUT_RANGE> & ranges)
+    explicit _checkFileLayoutRangeOverlap(const vector<TSK_DB_FILE_LAYOUT_RANGE> & ranges)
         : ranges(ranges),hasOverlap(false) {}
 
     bool getHasOverlap() const { return hasOverlap; }
