@@ -49,6 +49,9 @@ TskDbSqlite::TskDbSqlite(const TSK_TCHAR * a_dbFilePath, bool a_blkMapFlag)
     m_db = NULL;
     m_selectFilePreparedStmt = NULL;
     m_insertObjectPreparedStmt = NULL;
+
+	strcpy(m_dbFilePathUtf8, "");
+
 }
 #endif
 
@@ -107,8 +110,9 @@ int
     char *
         errmsg;
 
-    if (!m_db)
+    if (m_db == NULL) {
         return 1;
+    }
 
     if (sqlite3_exec(m_db, sql, callback, callback_arg,
         &errmsg) != SQLITE_OK) {
@@ -231,14 +235,14 @@ int
     }
 
     if (attempt_exec
-        ("CREATE TABLE tsk_db_info (schema_ver INTEGER, tsk_ver INTEGER);",
+        ("CREATE TABLE tsk_db_info (schema_ver INTEGER, tsk_ver INTEGER, schema_minor_ver INTEGER);",
         "Error creating tsk_db_info table: %s\n")) {
             return 1;
     }
 
     snprintf(foo, 1024,
-        "INSERT INTO tsk_db_info (schema_ver, tsk_ver) VALUES (%d, %d);",
-        TSK_SCHEMA_VER, TSK_VERSION_NUM);
+        "INSERT INTO tsk_db_info (schema_ver, tsk_ver, schema_minor_Ver) VALUES (%d, %d, %d);",
+        TSK_SCHEMA_VER, TSK_VERSION_NUM, TSK_SCHEMA_MINOR_VER);
     if (attempt_exec(foo, "Error adding data to tsk_db_info table: %s\n")) {
         return 1;
     }
@@ -271,11 +275,11 @@ int
         ("CREATE TABLE data_source_info (obj_id INTEGER PRIMARY KEY, device_id TEXT NOT NULL,  time_zone TEXT NOT NULL, FOREIGN KEY(obj_id) REFERENCES tsk_objects(obj_id));",
         "Error creating data_source_info table: %s\n")
         ||
-        attempt_exec
-        ("CREATE TABLE tsk_files (obj_id INTEGER PRIMARY KEY, fs_obj_id INTEGER, data_source_obj_id INTEGER NOT NULL, attr_type INTEGER, attr_id INTEGER, name TEXT NOT NULL, meta_addr INTEGER, meta_seq INTEGER, type INTEGER, has_layout INTEGER, has_path INTEGER, dir_type INTEGER, meta_type INTEGER, dir_flags INTEGER, meta_flags INTEGER, size INTEGER, ctime INTEGER, crtime INTEGER, atime INTEGER, mtime INTEGER, mode INTEGER, uid INTEGER, gid INTEGER, md5 TEXT, known INTEGER, parent_path TEXT, mime_type TEXT, "
-         "FOREIGN KEY(obj_id) REFERENCES tsk_objects(obj_id), FOREIGN KEY(fs_obj_id) REFERENCES tsk_fs_info(obj_id), FOREIGN KEY(data_source_obj_id) REFERENCES data_source_info(obj_id));",
-        "Error creating tsk_files table: %s\n")
-        ||
+		attempt_exec
+		("CREATE TABLE tsk_files (obj_id INTEGER PRIMARY KEY, fs_obj_id INTEGER, data_source_obj_id INTEGER NOT NULL, attr_type INTEGER, attr_id INTEGER, name TEXT NOT NULL, meta_addr INTEGER, meta_seq INTEGER, type INTEGER, has_layout INTEGER, has_path INTEGER, dir_type INTEGER, meta_type INTEGER, dir_flags INTEGER, meta_flags INTEGER, size INTEGER, ctime INTEGER, crtime INTEGER, atime INTEGER, mtime INTEGER, mode INTEGER, uid INTEGER, gid INTEGER, md5 TEXT, known INTEGER, parent_path TEXT, mime_type TEXT, extension TEXT , "
+			"FOREIGN KEY(obj_id) REFERENCES tsk_objects(obj_id), FOREIGN KEY(fs_obj_id) REFERENCES tsk_fs_info(obj_id), FOREIGN KEY(data_source_obj_id) REFERENCES data_source_info(obj_id));",
+			"Error creating tsk_files table: %s\n")
+		||
         attempt_exec
         ("CREATE TABLE file_encoding_types (encoding_type INTEGER PRIMARY KEY, name TEXT NOT NULL);",
         "Error creating file_encoding_types table: %s\n")
@@ -292,7 +296,7 @@ int
         "Error creating tsk_files_derived_method table: %s\n")
         ||
         attempt_exec
-        ("CREATE TABLE tag_names (tag_name_id INTEGER PRIMARY KEY, display_name TEXT UNIQUE, description TEXT NOT NULL, color TEXT NOT NULL)",
+        ("CREATE TABLE tag_names (tag_name_id INTEGER PRIMARY KEY, display_name TEXT UNIQUE, description TEXT NOT NULL, color TEXT NOT NULL, knownStatus INTEGER NOT NULL)",
         "Error creating tag_names table: %s\n")
         ||
         attempt_exec
@@ -313,9 +317,13 @@ int
         attempt_exec
         ("CREATE TABLE blackboard_artifacts (artifact_id INTEGER PRIMARY KEY, "
 		"obj_id INTEGER NOT NULL, "
+		"artifact_obj_id INTEGER NOT NULL, "
+		"data_source_obj_id INTEGER NOT NULL, "
 		"artifact_type_id INTEGER NOT NULL, "
 		"review_status_id INTEGER NOT NULL, "
         "FOREIGN KEY(obj_id) REFERENCES tsk_objects(obj_id), "
+		"FOREIGN KEY(artifact_obj_id) REFERENCES tsk_objects(obj_id), "
+		"FOREIGN KEY(data_source_obj_id) REFERENCES tsk_objects(obj_id), "
 		"FOREIGN KEY(artifact_type_id) REFERENCES blackboard_artifact_types(artifact_type_id), "
 		"FOREIGN KEY(review_status_id) REFERENCES review_statuses(review_status_id))",
         "Error creating blackboard_artifact table: %s\n")
@@ -356,7 +364,18 @@ int
         ||
         attempt_exec
         ("CREATE TABLE reports (report_id INTEGER PRIMARY KEY, path TEXT NOT NULL, crtime INTEGER NOT NULL, src_module_name TEXT NOT NULL, report_name TEXT NOT NULL)",
-            "Error creating reports table: %s\n")) {
+            "Error creating reports table: %s\n")
+		||
+		attempt_exec
+		("CREATE TABLE account_types (account_type_id INTEGER PRIMARY KEY, type_name TEXT UNIQUE NOT NULL, display_name TEXT NOT NULL)",
+			"Error creating account_types table: %s\n")
+		||
+		attempt_exec
+		("CREATE TABLE accounts (account_id INTEGER PRIMARY KEY, account_type_id INTEGER NOT NULL, account_unique_identifier TEXT NOT NULL,  UNIQUE(account_type_id, account_unique_identifier) , FOREIGN KEY(account_type_id) REFERENCES account_types(account_type_id))",
+			"Error creating accounts table: %s\n") ||
+		attempt_exec
+		("CREATE TABLE account_relationships (relationship_id INTEGER PRIMARY KEY, account1_id INTEGER NOT NULL, account2_id INTEGER NOT NULL, relationship_source_obj_id INTEGER NOT NULL,  date_time INTEGER, relationship_type INTEGER NOT NULL, data_source_obj_id INTEGER NOT NULL, UNIQUE(account1_id, account2_id, relationship_source_obj_id), FOREIGN KEY(account1_id) REFERENCES accounts(account_id), FOREIGN KEY(account2_id) REFERENCES accounts(account_id), FOREIGN KEY(relationship_source_obj_id) REFERENCES tsk_objects(obj_id), FOREIGN KEY(data_source_obj_id) REFERENCES tsk_objects(obj_id))",
+			"Error creating relationships table: %s\n") ) {
         return 1;
     }
 
@@ -378,28 +397,40 @@ int
 * Create indexes for the columns that are not primary keys and that we query on. 
 * @returns 1 on error, 0 on success
 */
-int
-    TskDbSqlite::createIndexes()
-{
-    return
-        // tsk_objects index
-        attempt_exec("CREATE INDEX parObjId ON tsk_objects(par_obj_id);",
-        "Error creating tsk_objects index on par_obj_id: %s\n") ||
-        // file layout index
-        attempt_exec("CREATE INDEX layout_objID ON tsk_file_layout(obj_id);",
-        "Error creating layout_objID index on tsk_file_layout: %s\n") ||
-        // blackboard indexes
-        attempt_exec("CREATE INDEX artifact_objID ON blackboard_artifacts(obj_id);",
-        "Error creating artifact_objID index on blackboard_artifacts: %s\n") ||
-        attempt_exec("CREATE INDEX artifact_typeID ON blackboard_artifacts(artifact_type_id);",
-        "Error creating artifact_objID index on blackboard_artifacts: %s\n") ||
-        attempt_exec("CREATE INDEX attrsArtifactID ON blackboard_attributes(artifact_id);",
-        "Error creating artifact_id index on blackboard_attributes: %s\n") ||
-		attempt_exec("CREATE INDEX mime_type ON tsk_files(dir_type,mime_type,type);",
-		"Error creating mime_type index on tsk_files: %s\n");
-        /*attempt_exec("CREATE INDEX attribute_artifactTypeId ON blackboard_attributes(artifact_type_id);",
-        "Error creating artifact_type_id index on blackboard_attributes: %s\n");
-        */
+int TskDbSqlite::createIndexes() {
+	return
+		// tsk_objects index
+		attempt_exec("CREATE INDEX parObjId ON tsk_objects(par_obj_id);",
+			"Error creating tsk_objects index on par_obj_id: %s\n") ||
+		// file layout index
+		attempt_exec("CREATE INDEX layout_objID ON tsk_file_layout(obj_id);",
+			"Error creating layout_objID index on tsk_file_layout: %s\n") ||
+		// blackboard indexes
+		attempt_exec("CREATE INDEX artifact_objID ON blackboard_artifacts(obj_id);",
+			"Error creating artifact_objID index on blackboard_artifacts: %s\n") ||
+		attempt_exec("CREATE INDEX artifact_artifact_objID ON blackboard_artifacts(artifact_obj_id);",
+			"Error creating artifact_artifact_objID index on blackboard_artifacts: %s\n") ||
+		attempt_exec("CREATE INDEX artifact_typeID ON blackboard_artifacts(artifact_type_id);",
+			"Error creating artifact_objID index on blackboard_artifacts: %s\n") ||
+		attempt_exec("CREATE INDEX attrsArtifactID ON blackboard_attributes(artifact_id);",
+			"Error creating artifact_id index on blackboard_attributes: %s\n") ||
+		//file type indexes
+		attempt_exec("CREATE INDEX mime_type ON tsk_files(dir_type,mime_type,type);", //mime type
+			"Error creating mime_type index on tsk_files: %s\n") ||
+		attempt_exec("CREATE INDEX file_extension ON tsk_files(extension);",  //file extenssion
+			"Error creating file_extension index on tsk_files: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_account1  ON account_relationships(account1_id);", 
+			"Error creating relationships_account1 index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_account2  ON account_relationships(account2_id);",
+			"Error creating relationships_account2 index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_relationship_source_obj_id  ON account_relationships(relationship_source_obj_id);",
+			"Error creating relationships_relationship_source_obj_id index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_date_time  ON account_relationships(date_time);",
+			"Error creating relationships_date_time index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_relationship_type  ON account_relationships(relationship_type);",
+			"Error creating relationships_relationship_type index on account_relationships: %s\n") ||
+		attempt_exec("CREATE INDEX relationships_data_source_obj_id  ON account_relationships(data_source_obj_id);",
+			"Error creating relationships_data_source_obj_id index on account_relationships: %s\n");
 }
 
 
@@ -858,205 +889,199 @@ int
 {
 
 
-    time_t
-        mtime = 0;
-    time_t
-        crtime = 0;
-    time_t
-        ctime = 0;
-    time_t
-        atime = 0;
-    TSK_OFF_T size = 0;
-    int
-        meta_type = 0;
-    int
-        meta_flags = 0;
-    int
-        meta_mode = 0;
-    int
-        gid = 0;
-    int
-        uid = 0;
-    int
-        type = TSK_FS_ATTR_TYPE_NOT_FOUND;
-    int
-        idx = 0;
-    char *zSQL;
+	time_t        mtime = 0;
+	time_t        crtime = 0;
+	time_t        ctime = 0;
+	time_t        atime = 0;
+	TSK_OFF_T size = 0;
+	int        meta_type = 0;
+	int        meta_flags = 0;
+	int        meta_mode = 0;
+	int        gid = 0;
+	int        uid = 0;
+	int        type = TSK_FS_ATTR_TYPE_NOT_FOUND;
+	int        idx = 0;
+	char *zSQL;
 
-    if (fs_file->name == NULL)
-        return 0;
+	if (fs_file->name == NULL)
+		return 0;
 
-    if (fs_file->meta) {
-        mtime = fs_file->meta->mtime;
-        atime = fs_file->meta->atime;
-        ctime = fs_file->meta->ctime;
-        crtime = fs_file->meta->crtime;
-        meta_type = fs_file->meta->type;
-        meta_flags = fs_file->meta->flags;
-        meta_mode = fs_file->meta->mode;
-        gid = fs_file->meta->gid;
-        uid = fs_file->meta->uid;
-    }
+	if (fs_file->meta) {
+		mtime = fs_file->meta->mtime;
+		atime = fs_file->meta->atime;
+		ctime = fs_file->meta->ctime;
+		crtime = fs_file->meta->crtime;
+		meta_type = fs_file->meta->type;
+		meta_flags = fs_file->meta->flags;
+		meta_mode = fs_file->meta->mode;
+		gid = fs_file->meta->gid;
+		uid = fs_file->meta->uid;
+	}
 
-    size_t attr_nlen = 0;
-    if (fs_attr) {
-        type = fs_attr->type;
-        idx = fs_attr->id;
-        size = fs_attr->size;
-        if (fs_attr->name) {
-            if ((fs_attr->type != TSK_FS_ATTR_TYPE_NTFS_IDXROOT) ||
-                (strcmp(fs_attr->name, "$I30") != 0)) {
-                    attr_nlen = strlen(fs_attr->name);
-            }
-        }
-    }
+	size_t attr_nlen = 0;
+	if (fs_attr) {
+		type = fs_attr->type;
+		idx = fs_attr->id;
+		size = fs_attr->size;
+		if (fs_attr->name) {
+			if ((fs_attr->type != TSK_FS_ATTR_TYPE_NTFS_IDXROOT) ||
+				(strcmp(fs_attr->name, "$I30") != 0)) {
+				attr_nlen = strlen(fs_attr->name);
+			}
+		}
+	}
 
-    // combine name and attribute name
-    size_t len = strlen(fs_file->name->name);
-    char *
-        name;
-    size_t nlen = len + attr_nlen + 11; // Extra space for possible colon and '-slack'
-    if ((name = (char *) tsk_malloc(nlen)) == NULL) {
-        return 1;
-    }
+	// combine name and attribute name
+	size_t len = strlen(fs_file->name->name);
+	char * name;
+	size_t nlen = len + attr_nlen + 11; // Extra space for possible colon and '-slack'
+	if ((name = (char *)tsk_malloc(nlen)) == NULL) {
+		return 1;
+	}
 
-    strncpy(name, fs_file->name->name, nlen);
+	strncpy(name, fs_file->name->name, nlen);
 
-    // Add the attribute name
-    if (attr_nlen > 0) {
+	char extension[24] ="";
+	extractExtension(name, extension);
+
+	// Add the attribute name
+	if (attr_nlen > 0) {
         strncat(name, ":", nlen-strlen(name));
         strncat(name, fs_attr->name, nlen-strlen(name));
-    }
+	}
 
-    // clean up path
-    // +2 = space for leading slash and terminating null
-    size_t path_len = strlen(path) + 2;
-    char *escaped_path;
+	// clean up path
+	// +2 = space for leading slash and terminating null
+	size_t path_len = strlen(path) + 2;
+	char *escaped_path;
     if ((escaped_path = (char *) tsk_malloc(path_len)) == NULL) { 
-        free(name);
-        return 1;
-    }
+		free(name);
+		return 1;
+	}
 
-    strncpy(escaped_path, "/", path_len);
-    strncat(escaped_path, path, path_len - strlen(escaped_path));
+	strncpy(escaped_path, "/", path_len);
+	strncat(escaped_path, path, path_len - strlen(escaped_path));
 
-    char *md5TextPtr = NULL;
-    char md5Text[48];
+	char *md5TextPtr = NULL;
+	char md5Text[48];
 
-    // if md5 hashes are being used
-    if (md5 != NULL) {
-        // copy the hash as hexidecimal into the buffer
-        for (int i = 0; i < 16; i++) {
+	// if md5 hashes are being used
+	if (md5 != NULL) {
+		// copy the hash as hexidecimal into the buffer
+		for (int i = 0; i < 16; i++) {
             sprintf(&(md5Text[i*2]), "%x%x", (md5[i] >> 4) & 0xf,
-                md5[i] & 0xf);
-        }
-        md5TextPtr = md5Text;
-    }
+				md5[i] & 0xf);
+		}
+		md5TextPtr = md5Text;
+	}
 
 
-    if (addObject(TSK_DB_OBJECT_TYPE_FILE, parObjId, objId)) {
-        free(name);
-        free(escaped_path);
-        return 1;
-    }
+	if (addObject(TSK_DB_OBJECT_TYPE_FILE, parObjId, objId)) {
+		free(name);
+		free(escaped_path);
+		return 1;
+	}
 
-    zSQL = sqlite3_mprintf(
-        "INSERT INTO tsk_files (fs_obj_id, obj_id, data_source_obj_id, type, attr_type, attr_id, name, meta_addr, meta_seq, dir_type, meta_type, dir_flags, meta_flags, size, crtime, ctime, atime, mtime, mode, gid, uid, md5, known, parent_path) "
-        "VALUES ("
-        "%" PRId64 ",%" PRId64 ","
-        "%" PRId64 "," 
-        "%d,"
-        "%d,%d,'%q',"
-        "%" PRIuINUM ",%d,"
-        "%d,%d,%d,%d,"
-        "%" PRIuOFF ","
-        "%llu,%llu,%llu,%llu,"
-        "%d,%d,%d,%Q,%d,"
-        "'%q')",
-        fsObjId, objId,
-        dataSourceObjId,
-        TSK_DB_FILES_TYPE_FS,
-        type, idx, name,
-        fs_file->name->meta_addr, fs_file->name->meta_seq, 
-        fs_file->name->type, meta_type, fs_file->name->flags, meta_flags,
-        size, 
-        (unsigned long long)crtime, (unsigned long long)ctime,(unsigned long long) atime,(unsigned long long) mtime, 
-        meta_mode, gid, uid, md5TextPtr, known,
-        escaped_path);
+	zSQL = sqlite3_mprintf(
+		"INSERT INTO tsk_files (fs_obj_id, obj_id, data_source_obj_id, type, attr_type, attr_id, name, meta_addr, meta_seq, dir_type, meta_type, dir_flags, meta_flags, size, crtime, ctime, atime, mtime, mode, gid, uid, md5, known, parent_path, extension) "
+		"VALUES ("
+		"%" PRId64 ",%" PRId64 ","
+		"%" PRId64 ","
+		"%d,"
+		"%d,%d,'%q',"
+		"%" PRIuINUM ",%d,"
+		"%d,%d,%d,%d,"
+		"%" PRIuOFF ","
+		"%llu,%llu,%llu,%llu,"
+		"%d,%d,%d,%Q,%d,"
+		"'%q','%q')",
+		fsObjId, objId,
+		dataSourceObjId,
+		TSK_DB_FILES_TYPE_FS,
+		type, idx, name,
+		fs_file->name->meta_addr, fs_file->name->meta_seq,
+		fs_file->name->type, meta_type, fs_file->name->flags, meta_flags,
+		size,
+		(unsigned long long)crtime, (unsigned long long)ctime, (unsigned long long) atime, (unsigned long long) mtime,
+		meta_mode, gid, uid, md5TextPtr, known,
+		escaped_path, extension);
 
-    if (attempt_exec(zSQL, "TskDbSqlite::addFile: Error adding data to tsk_files table: %s\n")) {
-        free(name);
-        free(escaped_path);
-        sqlite3_free(zSQL);
-        return 1;
-    }
+	if (attempt_exec(zSQL, "TskDbSqlite::addFile: Error adding data to tsk_files table: %s\n")) {
+		free(name);
+		free(escaped_path);
+		sqlite3_free(zSQL);
+		return 1;
+	}
 
-    //if dir, update parent id cache (do this before objId may be changed creating the slack file)
-    if (meta_type == TSK_FS_META_TYPE_DIR) {
-        std::string fullPath = std::string(path) + fs_file->name->name;
-        storeObjId(fsObjId, fs_file, fullPath.c_str(), objId);
-    }
+	//if dir, update parent id cache (do this before objId may be changed creating the slack file)
+    if (TSK_FS_IS_DIR_META(meta_type)){
+		std::string fullPath = std::string(path) + fs_file->name->name;
+		storeObjId(fsObjId, fs_file, fullPath.c_str(), objId);
+	}
 
-    // Add entry for the slack space.
+	// Add entry for the slack space.
 	// Current conditions for creating a slack file:
-    //   - File name is not empty, "." or ".."
+	//   - File name is not empty, "." or ".."
 	//   - Data is non-resident
 	//   - The allocated size is greater than the initialized file size
-    //     See github issue #756 on why initsize and not size.
+	//     See github issue #756 on why initsize and not size.
 	//   - The data is not compressed
     if((fs_attr != NULL)
            && ((strlen(name) > 0 ) && (! TSK_FS_ISDOT(name)))
-           && (!(fs_file->meta->flags & TSK_FS_META_FLAG_COMP))
-           && (fs_attr->flags & TSK_FS_ATTR_NONRES) 
+		&& (!(fs_file->meta->flags & TSK_FS_META_FLAG_COMP))
+		&& (fs_attr->flags & TSK_FS_ATTR_NONRES)
            && (fs_attr->nrd.allocsize >  fs_attr->nrd.initsize)){
-        strncat(name, "-slack", 6);
-        TSK_OFF_T slackSize = fs_attr->nrd.allocsize - fs_attr->nrd.initsize;
+		strncat(name, "-slack", 6);
+		if (strlen(extension) > 0) {
+			strncat(extension, "-slack", 6);
+		}
+		TSK_OFF_T slackSize = fs_attr->nrd.allocsize - fs_attr->nrd.initsize;
 
-        if (addObject(TSK_DB_OBJECT_TYPE_FILE, parObjId, objId)) {
-            free(name);
-            free(escaped_path);
-            return 1;
-        }
+		if (addObject(TSK_DB_OBJECT_TYPE_FILE, parObjId, objId)) {
+			free(name);
+			free(escaped_path);
+			return 1;
+		}
 
-        // Run the same insert with the new name, size, and type
-        zSQL = sqlite3_mprintf(
-        "INSERT INTO tsk_files (fs_obj_id, obj_id, data_source_obj_id, type, attr_type, attr_id, name, meta_addr, meta_seq, dir_type, meta_type, dir_flags, meta_flags, size, crtime, ctime, atime, mtime, mode, gid, uid, md5, known, parent_path) "
-        "VALUES ("
-        "%" PRId64 ",%" PRId64 ","
-        "%" PRId64 "," 
-        "%d,"
-        "%d,%d,'%q',"
-        "%" PRIuINUM ",%d,"
-        "%d,%d,%d,%d,"
-        "%" PRIuOFF ","
-        "%llu,%llu,%llu,%llu,"
-        "%d,%d,%d,%Q,%d,"
-        "'%q')",
-        fsObjId, objId,
-        dataSourceObjId,
-        TSK_DB_FILES_TYPE_SLACK,
-        type, idx, name,
-        fs_file->name->meta_addr, fs_file->name->meta_seq, 
-        TSK_FS_NAME_TYPE_REG, TSK_FS_META_TYPE_REG, fs_file->name->flags, meta_flags,
-        slackSize, 
+		// Run the same insert with the new name, size, and type
+		zSQL = sqlite3_mprintf(
+			"INSERT INTO tsk_files (fs_obj_id, obj_id, data_source_obj_id, type, attr_type, attr_id, name, meta_addr, meta_seq, dir_type, meta_type, dir_flags, meta_flags, size, crtime, ctime, atime, mtime, mode, gid, uid, md5, known, parent_path,extension) "
+			"VALUES ("
+			"%" PRId64 ",%" PRId64 ","
+			"%" PRId64 ","
+			"%d,"
+			"%d,%d,'%q',"
+			"%" PRIuINUM ",%d,"
+			"%d,%d,%d,%d,"
+			"%" PRIuOFF ","
+			"%llu,%llu,%llu,%llu,"
+			"%d,%d,%d,NULL,%d,"
+			"'%q','%q')",
+			fsObjId, objId,
+			dataSourceObjId,
+			TSK_DB_FILES_TYPE_SLACK,
+			type, idx, name,
+			fs_file->name->meta_addr, fs_file->name->meta_seq,
+			TSK_FS_NAME_TYPE_REG, TSK_FS_META_TYPE_REG, fs_file->name->flags, meta_flags,
+			slackSize,
         (unsigned long long)crtime, (unsigned long long)ctime,(unsigned long long) atime,(unsigned long long) mtime, 
-        meta_mode, gid, uid, md5TextPtr, known,
-        escaped_path);
+			meta_mode, gid, uid, known,
+			escaped_path,extension);
 
-        if (attempt_exec(zSQL, "TskDbSqlite::addFile: Error adding data to tsk_files table: %s\n")) {
-            free(name);
-            free(escaped_path);
-            sqlite3_free(zSQL);
-            return 1;
-        }
-    }
+		if (attempt_exec(zSQL, "TskDbSqlite::addFile: Error adding data to tsk_files table: %s\n")) {
+			free(name);
+			free(escaped_path);
+			sqlite3_free(zSQL);
+			return 1;
+		}
+	}
 
-    sqlite3_free(zSQL);
+	sqlite3_free(zSQL);
 
-    free(name);
-    free(escaped_path);
+	free(name);
+	free(escaped_path);
 
-    return 0;
+	return 0;
 }
 
 
@@ -1296,7 +1321,7 @@ typedef struct _checkFileLayoutRangeOverlap{
     const vector<TSK_DB_FILE_LAYOUT_RANGE> & ranges;
     bool hasOverlap;
 
-    _checkFileLayoutRangeOverlap(const vector<TSK_DB_FILE_LAYOUT_RANGE> & ranges)
+    explicit _checkFileLayoutRangeOverlap(const vector<TSK_DB_FILE_LAYOUT_RANGE> & ranges)
         : ranges(ranges),hasOverlap(false) {}
 
     bool getHasOverlap() const { return hasOverlap; }
