@@ -25,9 +25,15 @@
  */
 #include "tsk_fs_i.h"
 
+#include <time.h>
+
+#ifndef TZNAME
+#define TZNAME __tzname
+#endif
+
 char tsk_fs_name_type_str[TSK_FS_NAME_TYPE_STR_MAX][2] =
     { "-", "p", "c", "d", "b", "r",
-    "l", "s", "h", "w", "v"
+    "l", "s", "h", "w", "v", "V"
 };
 
 /**
@@ -416,7 +422,7 @@ tsk_fs_name_print(FILE * hFile, const TSK_FS_FILE * fs_file,
          * printed as a directory
          */
         if ((fs_attr) && (fs_attr->type == TSK_FS_ATTR_TYPE_NTFS_DATA) &&
-            (fs_file->meta->type == TSK_FS_META_TYPE_DIR)) {
+            (TSK_FS_IS_DIR_META(fs_file->meta->type))){
             tsk_fprintf(hFile, "r ");
         }
         else {
