@@ -72,10 +72,9 @@ static void
 iso9660_inode_list_free(TSK_FS_INFO * fs)
 {
     ISO_INFO *iso = (ISO_INFO *) fs;
-    iso9660_inode_node *tmp;
 
     while (iso->in_list) {
-        tmp = iso->in_list;
+        iso9660_inode_node *tmp = iso->in_list;
         iso->in_list = iso->in_list->next;
         free(tmp);
     }
@@ -142,7 +141,6 @@ parse_susp(TSK_FS_INFO * fs, char *buf, int count, FILE * hFile)
             // read the continued buffer and parse it
             if ((tsk_getu32(fs->endian, ce->blk_m) < fs->last_block) &&
                 (tsk_getu32(fs->endian, ce->offset_m) < fs->block_size)) {
-                ssize_t cnt;
                 TSK_OFF_T off;
                 char *buf2;
 
@@ -155,7 +153,7 @@ parse_susp(TSK_FS_INFO * fs, char *buf, int count, FILE * hFile)
                         ce->celen_m));
 
                 if (buf2 != NULL) {
-                    cnt =
+                    ssize_t cnt =
                         tsk_fs_read(fs, off, buf2,
                         tsk_getu32(fs->endian, ce->celen_m));
                     if (cnt == tsk_getu32(fs->endian, ce->celen_m)) {
@@ -509,6 +507,7 @@ iso9660_load_inodes_dir(TSK_FS_INFO * fs, TSK_OFF_T a_offs, int count,
                     tsk_error_set_errno(TSK_ERR_FS_ARG);
                     tsk_error_set_errstr
                         ("iso9660_load_inodes_dir: Name argument specified is too long");
+                    free(in_node);
                     return -1;
                 }
                 strncpy(in_node->inode.fn, a_fn, ISO9660_MAXNAMLEN_STD + 1);
@@ -618,6 +617,7 @@ iso9660_load_inodes_dir(TSK_FS_INFO * fs, TSK_OFF_T a_offs, int count,
                     if (tsk_verbose)
                         tsk_fprintf(stderr,
                                     "iso9660_load_inodes_dir: length of name after processing is 0. bailing\n");
+                    free(in_node);
                     break;
                     
                 }
@@ -636,16 +636,18 @@ iso9660_load_inodes_dir(TSK_FS_INFO * fs, TSK_OFF_T a_offs, int count,
                     tsk_fprintf(stderr,
                                 "iso9660_load_inodes_dir: file starts past end of image (%"PRIu32"). bailing\n",
                                 tsk_getu32(fs->endian, dentry->ext_loc_m));
+                free(in_node);
                 break;
             }
             in_node->offset =
                 tsk_getu32(fs->endian, dentry->ext_loc_m) * fs->block_size;
             
-            if (tsk_getu32(fs->endian, in_node->inode.dr.data_len_m) + in_node->offset > fs->block_count * fs->block_size) {
+            if (tsk_getu32(fs->endian, in_node->inode.dr.data_len_m) + in_node->offset > (TSK_OFF_T)(fs->block_count * fs->block_size)) {
                 if (tsk_verbose)
                     tsk_fprintf(stderr,
                                 "iso9660_load_inodes_dir: file ends past end of image (%"PRIu32" bytes). bailing\n",
                                 tsk_getu32(fs->endian, in_node->inode.dr.data_len_m) + in_node->offset);
+                free(in_node);
                 break;
             }
             /* record size to make sure fifos show up as unique files */
@@ -678,6 +680,7 @@ iso9660_load_inodes_dir(TSK_FS_INFO * fs, TSK_OFF_T a_offs, int count,
                     if (tsk_verbose)
                         tsk_fprintf(stderr,
                                     "iso9660_load_inodes_dir: parse_susp returned error (%s). bailing\n", tsk_error_get());
+                    free(in_node);
                     break;
                 }
                 
@@ -888,7 +891,6 @@ iso9660_load_inodes_pt(ISO_INFO * iso)
     char fn[ISO9660_MAXNAMLEN_STD + 1]; /* store current directory name */
     path_table_rec dir;
     TSK_OFF_T pt_offs;          /* offset of where we are in path table */
-    size_t pt_len;              /* bytes left in path table */
     TSK_OFF_T extent;           /* offset of extent for current directory */
     ssize_t cnt;
     uint8_t is_first = 1;
@@ -922,6 +924,7 @@ iso9660_load_inodes_pt(ISO_INFO * iso)
 
     /* Now look for unique files in the primary descriptors */
     for (p = iso->pvd; p != NULL; p = p->next) {
+        size_t pt_len;              /* bytes left in path table */
 
         pt_offs =
             (TSK_OFF_T) (tsk_getu32(fs->endian,
@@ -1128,22 +1131,30 @@ static void
 iso9660_close(TSK_FS_INFO * fs)
 {
     ISO_INFO *iso = (ISO_INFO *) fs;
-    iso9660_pvd_node *p;
-    iso9660_svd_node *s;
 
     fs->tag = 0;
+
     while (iso->pvd != NULL) {
-        p = iso->pvd;
+        iso9660_pvd_node *p = iso->pvd;
         iso->pvd = iso->pvd->next;
         free(p);
     }
 
     while (iso->svd != NULL) {
-        s = iso->svd;
+        iso9660_svd_node *s = iso->svd;
         iso->svd = iso->svd->next;
         free(s);
     }
 
+    while (iso->in_list != NULL) {
+        iso9660_inode_node *in = iso->in_list;
+        iso->in_list = iso->in_list->next;
+        if (in->inode.rr != NULL) {
+            free(in->inode.rr);
+        }
+        free(in);
+    }
+
     tsk_fs_free(fs);
 }
 
@@ -1547,11 +1558,12 @@ iso9660_make_data_run(TSK_FS_FILE * a_fs_file)
     else if (a_fs_file->meta->attr_state == TSK_FS_META_ATTR_ERROR) {
         return 1;
     }
+
     // not sure why this would ever happen, but...
-    else if (a_fs_file->meta->attr != NULL) {
+    if (a_fs_file->meta->attr != NULL) {
         tsk_fs_attrlist_markunused(a_fs_file->meta->attr);
     }
-    else if (a_fs_file->meta->attr == NULL) {
+    else  {
         a_fs_file->meta->attr = tsk_fs_attrlist_alloc();
     }
 
@@ -2018,7 +2030,7 @@ iso9660_print_rockridge(FILE * hFile, rockridge_ext * rr)
  * @returns 1 on error and 0 on success
  */
 static uint8_t
-iso9660_istat(TSK_FS_INFO * fs, FILE * hFile, TSK_INUM_T inum,
+iso9660_istat(TSK_FS_INFO * fs, TSK_FS_ISTAT_FLAG_ENUM istat_flags, FILE * hFile, TSK_INUM_T inum,
     TSK_DADDR_T numblock, int32_t sec_skew)
 {
     ISO_INFO *iso = (ISO_INFO *) fs;
@@ -2182,8 +2194,21 @@ iso9660_istat(TSK_FS_INFO * fs, FILE * hFile, TSK_INUM_T inum,
         tsk_fs_time_to_str(fs_file->meta->atime, timeBuf));
 
     tsk_fprintf(hFile, "\nSectors:\n");
-    /* since blocks are all contiguous, print them here to simplify file_walk */
-    {
+    if (istat_flags & TSK_FS_ISTAT_RUNLIST) {
+        const TSK_FS_ATTR *fs_attr_default =
+            tsk_fs_file_attr_get_type(fs_file,
+                TSK_FS_ATTR_TYPE_DEFAULT, 0, 0);
+        if (fs_attr_default && (fs_attr_default->flags & TSK_FS_ATTR_NONRES)) {
+            if (tsk_fs_attr_print(fs_attr_default, hFile)) {
+                tsk_fprintf(hFile, "\nError creating run lists\n");
+                tsk_error_print(hFile);
+                tsk_error_reset();
+            }
+        }
+    }
+    else {
+        /* since blocks are all contiguous, print them here to simplify file_walk */
+   
         int block = tsk_getu32(fs->endian, dinode->dr.ext_loc_m);
         TSK_OFF_T size = fs_file->meta->size;
         int rowcount = 0;
@@ -2343,8 +2368,10 @@ load_vol_desc(TSK_FS_INFO * fs)
         magic_seen = 1;
 
         // see if we are done
-        if (vd->type == ISO9660_VOL_DESC_SET_TERM)
+        if (vd->type == ISO9660_VOL_DESC_SET_TERM) {
+            free(vd);
             break;
+        }
 
         switch (vd->type) {
 
@@ -2416,6 +2443,7 @@ load_vol_desc(TSK_FS_INFO * fs)
 
             /* boot records are just read and discarded for now... */
         case ISO9660_BOOT_RECORD:
+            free(vd);
 #if 0
             cnt = tsk_fs_read(fs, offs, (char *) b, sizeof(iso_bootrec));
             if (cnt != sizeof(iso_bootrec)) {
@@ -2429,6 +2457,10 @@ load_vol_desc(TSK_FS_INFO * fs)
             offs += sizeof(iso_bootrec);
 #endif
             break;
+
+        default:
+            free(vd);
+            break;
         }
     }
 
@@ -2494,6 +2526,13 @@ iso9660_open(TSK_IMG_INFO * img_info, TSK_OFF_T offset,
         return NULL;
     }
 
+    if (img_info->sector_size == 0) {
+        tsk_error_reset();
+        tsk_error_set_errno(TSK_ERR_FS_ARG);
+        tsk_error_set_errstr("iso9660_open: sector size is 0");
+        return NULL;
+    }
+
     if (tsk_verbose) {
         tsk_fprintf(stderr, "iso9660_open img_info: %" PRIu64
             " ftype: %" PRIu8 " test: %" PRIu8 "\n", (uint64_t) img_info,
@@ -2591,7 +2630,7 @@ iso9660_open(TSK_IMG_INFO * img_info, TSK_OFF_T offset,
 
     fs->first_block = 0;
     fs->last_block = fs->last_block_act = fs->block_count - 1;
-
+    
     // determine the last block we have in this image
     if ((TSK_DADDR_T) ((img_info->size - offset) / fs->block_size) <
         fs->block_count)
